@@ -2,10 +2,10 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("1.6.1", "1.6.1")]
-[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "i686", "2010-05-07 14:50:09 EDT")]
+[assembly: ApplicationVersion ("2.1.0", "2.1.0")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2011-05-12 19:36:49 CEST")]
 
-[assembly: AssemblyVersion ("1.6.0.0")]
+[assembly: AssemblyVersion ("2.1.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
 [assembly: AssemblyDescription ("Banshee Media Player")]
 [assembly: AssemblyCopyright ("Copyright (C) 2005-2010 Novell Inc. and others")]
